projectal.entities.customer API documentation

# projectal.entities.customer

View Source

    from projectal.entity import Entity
    from projectal.linkers import *

    class Customer(Entity, ContactLinker, FileLinker, LocationLinker):
        """
        Implementation of the [Customer](https://projectal.com/docs/latest/#tag/Customer) API.
        """
        _path = 'customer'
        _name = 'CUSTOMER'

class Customer(projectal.entity.Entity, projectal.linkers.ContactLinker, projectal.linkers.FileLinker, projectal.linkers.LocationLinker):
View Source

    class Customer(Entity, ContactLinker, FileLinker, LocationLinker):
        """
        Implementation of the [Customer](https://projectal.com/docs/latest/#tag/Customer) API.
        """
        _path = 'customer'
        _name = 'CUSTOMER'

Implementation of the Customer API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  create
  save
  clone
  history
  list
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
projectal.linkers.ContactLinker
  link_contact
  unlink_contact
projectal.linkers.FileLinker
  link_file
  unlink_file
projectal.linkers.LocationLinker
  link_location
  unlink_location
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy